from distutils.core import setup

setup(
    name='nester_ht7714',
    version='1.1.2',
    py_modules=['nester'],
    author='hfpython',
    author_email='hfpython@headfirstlabs.com',
    url='http://www.headfirstlabs.com',
    desceiption='A simple printer of nested lists',

)
